@@ -7,7 +7,7 @@ use Exporter 'import';
 use ExtUtils::MakeMaker;
 use XS::Install::Payload;
 
-our $VERSION = '1.0.5';
+our $VERSION = '1.0.6';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile makemaker_args/;
@@ -132,6 +132,8 @@ sub makemaker_args {
         my $cppv = int($use_cpp);
         $cppv = 11 if $cppv < 11;
         _string_merge($params{CCFLAGS}, "-std=c++$cppv");
+        
+        _check_sjlj();
     }
     
     # inject ParseXS plugins into xsubpp
@@ -750,4 +752,18 @@ sub _module_info_write {
     chmod $restore_mode, $file if $restore_mode; # restore old perms if we changed it
 }
 
+sub _check_sjlj {
+    return unless $^O eq 'MSWin32' && $Config{myuname} =~ /strawberry/;
+    my $out = `c++ -v 2>&1`;
+    if ($out =~ /--enable-sjlj-exceptions/) {
+        die "***************************************************************\n".
+            "You are using c++ compiler with SJLJ exceptions enabled.\n".
+            "It makes it impossible to use C++ exceptions and perl together.\n".
+            "You need to use compiler with DWARF2 or SEH exceptions configured.\n".
+            "If you are using Strawberry Perl, install Strawberry 5.26 or higher\n".
+            "where they use mingw with SEH exceptions.\n".
+            "***************************************************************\n";
+    }
+}
+
 1;
